pub struct RectF {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
A floating point, rectangular, axis-aligned region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32The location of the origin of the rectangle in the x-axis.
y: f32The location of the origin of the rectangle in the y-axis.
width: f32The distance along the x-axis.
If width is positive, the region includes x values starting at x and
increasing along the x-axis. If width is negative, the region includes
x values starting at x and decreasing along the x-axis.
height: f32The distance along the y-axis.
If height is positive, the region includes y values starting at y
and increasing along the y-axis. If height is negative, the region
includes y values starting at y and decreasing along the y-axis.